Documentation
¶
Index ¶
- Constants
- func Azalt(tjdUt float64, calcFlag int, geopos []float64, atpress float64, attemp float64, ...)
- func AzaltRev(tjdUt float64, calcFlag int, geopos []float64, xin []float64, xout []float64)
- func Calc(tjd float64, ipl int, iflag int, xx []float64, serr []byte) int32
- func CalcPctr(tjd float64, ipl int, iplctr int, iflag int, xxret []float64, serr []byte) int32
- func CalcUt(tjdUt float64, ipl int, iflag int, xx []float64, serr []byte) int32
- func Close()
- func Cotrans(xpo []float64, xpn []float64, eps float64)
- func CotransSp(xpo []float64, xpn []float64, eps float64)
- func Cs2degstr(t int, a []byte) *byte
- func Cs2lonlatstr(t int, pchar byte, mchar byte, s []byte) *byte
- func Cs2timestr(t int, sep int, suppressZero int, a []byte) *byte
- func Csnorm(p int32) int32
- func Csroundsec(x int32) int32
- func D2l(x float64) int32
- func DateConversion(y int, m int, d int, utime float64, c byte, tjd []float64) int32
- func DayOfWeek(jd float64) int32
- func DegMidp(x1 float64, x0 float64) float64
- func Degnorm(x float64) float64
- func Deltat(tjd float64) float64
- func DeltatEx(tjd float64, iflag int, serr []byte) float64
- func Difcs2n(p1 int, p2 int32) int32
- func Difcsn(p1 int, p2 int32) int32
- func Difdeg2n(p1 float64, p2 float64) float64
- func Difdegn(p1 float64, p2 float64) float64
- func Difrad2n(p1 float64, p2 float64) float64
- func Fixstar(star []byte, tjd float64, iflag int, xx []float64, serr []byte) int32
- func Fixstar2(star []byte, tjd float64, iflag int, xx []float64, serr []byte) int32
- func Fixstar2Mag(star []byte, mag []float64, serr []byte) int32
- func Fixstar2Ut(star []byte, tjdUt float64, iflag int, xx []float64, serr []byte) int32
- func FixstarMag(star []byte, mag []float64, serr []byte) int32
- func FixstarUt(star []byte, tjdUt float64, iflag int, xx []float64, serr []byte) int32
- func GauquelinSector(tUt float64, ipl int, starname []byte, iflag int, imeth int, geopos []float64, ...) int32
- func GetAstroModels(samod []byte, sdet []byte, iflag int32)
- func GetAyanamsa(tjdEt float64) float64
- func GetAyanamsaEx(tjdEt float64, iflag int, daya []float64, serr []byte) int32
- func GetAyanamsaExUt(tjdUt float64, iflag int, daya []float64, serr []byte) int32
- func GetAyanamsaName(isidmode int32) string
- func GetAyanamsaUt(tjdUt float64) float64
- func GetCurrentFileData(ifno int, tfstart []float64, tfend []float64, denum []int32) string
- func GetLibraryPath(arg0 []byte) *byte
- func GetOrbitalElements(tjdEt float64, ipl int, iflag int, dret []float64, serr []byte) int32
- func GetPlanetName(ipl int, spname []byte) *byte
- func GetTidAcc() float64
- func HeliacalAngle(tjdut float64, dgeo []float64, datm []float64, dobs []float64, helflag int, ...) int32
- func HeliacalPhenoUt(tjdUt float64, geopos []float64, datm []float64, dobs []float64, ...) int32
- func HeliacalUt(tjdstartUt float64, geopos []float64, datm []float64, dobs []float64, ...) int32
- func HelioCross(ipl int32, x2cross float64, jdEt float64, iflag int32, dir int32, ...) int32
- func HelioCrossUt(ipl int32, x2cross float64, jdUt float64, iflag int32, dir int32, ...) int32
- func HouseName(hsys int32) *byte
- func HousePos(armc float64, geolat float64, eps float64, hsys int, xpin []float64, ...) float64
- func Houses(tjdUt float64, geolat float64, geolon float64, hsys int, cusps []float64, ...) int32
- func HousesArmc(armc float64, geolat float64, eps float64, hsys int, cusps []float64, ...) int32
- func HousesArmcEx2(armc float64, geolat float64, eps float64, hsys int, cusps []float64, ...) int32
- func HousesEx(tjdUt float64, iflag int, geolat float64, geolon float64, hsys int, ...) int32
- func HousesEx2(tjdUt float64, iflag int, geolat float64, geolon float64, hsys int, ...) int32
- func JdetToUtc(tjdEt float64, gregflag int, iyear []int, imonth []int, iday []int, ...)
- func Jdut1ToUtc(tjdUt float64, gregflag int, iyear []int, imonth []int, iday []int, ...)
- func Julday(year int, month int, day int, hour float64, gregflag int32) float64
- func LatToLmt(tjdLat float64, geolon float64, tjdLmt []float64, serr []byte) int32
- func LmtToLat(tjdLmt float64, geolon float64, tjdLat []float64, serr []byte) int32
- func LunEclipseHow(tjdUt float64, ifl int, geopos []float64, attr []float64, serr []byte) int32
- func LunEclipseWhen(tjdStart float64, ifl int, ifltype int, tret []float64, backward int, ...) int32
- func LunEclipseWhenLoc(tjdStart float64, ifl int, geopos []float64, tret []float64, attr []float64, ...) int32
- func LunOccultWhenGlob(tjdStart float64, ipl int, starname []byte, ifl int, ifltype int, ...) int32
- func LunOccultWhenLoc(tjdStart float64, ipl int, starname []byte, ifl int, geopos []float64, ...) int32
- func LunOccultWhere(tjd float64, ipl int, starname []byte, ifl int, geopos []float64, ...) int32
- func Mooncross(x2cross float64, jdEt float64, flag int32, serr []byte) float64
- func MooncrossNode(jdEt float64, flag int32, xlon []float64, xlat []float64, serr []byte) float64
- func MooncrossNodeUt(jdUt float64, flag int32, xlon []float64, xlat []float64, serr []byte) float64
- func MooncrossUt(x2cross float64, jdUt float64, flag int32, serr []byte) float64
- func NodAps(tjdEt float64, ipl int, iflag int, method int, xnasc []float64, ...) int32
- func NodApsUt(tjdUt float64, ipl int, iflag int, method int, xnasc []float64, ...) int32
- func OrbitMaxMinTrueDistance(tjdEt float64, ipl int, iflag int, dmax []float64, dmin []float64, ...) int32
- func Pheno(tjd float64, ipl int, iflag int, attr []float64, serr []byte) int32
- func PhenoUt(tjdUt float64, ipl int, iflag int, attr []float64, serr []byte) int32
- func RadMidp(x1 float64, x0 float64) float64
- func Radnorm(x float64) float64
- func Refrac(inalt float64, atpress float64, attemp float64, calcFlag int32) float64
- func RefracExtended(inalt float64, geoalt float64, atpress float64, attemp float64, ...) float64
- func Revjul(jd float64, gregflag int, jyear []int, jmon []int, jday []int, jut []float64)
- func RiseTrans(tjdUt float64, ipl int, starname []byte, epheflag int, rsmi int, ...) int32
- func RiseTransTrueHor(tjdUt float64, ipl int, starname []byte, epheflag int, rsmi int, ...) int32
- func SetAstroModels(samod []byte, iflag int32)
- func SetDeltaTUserdef(dt float64)
- func SetEphePath(path []byte)
- func SetInterpolateNut(doInterpolate int32)
- func SetJplFile(fname []byte)
- func SetLapseRate(lapseRate float64)
- func SetSidMode(sidMode int, t0 float64, ayanT0 float64)
- func SetTidAcc(tAcc float64)
- func SetTopo(geolon float64, geolat float64, geoalt float64)
- func Sidtime(tjdUt float64) float64
- func Sidtime0(tjdUt float64, eps float64, nut float64) float64
- func SolEclipseHow(tjd float64, ifl int, geopos []float64, attr []float64, serr []byte) int32
- func SolEclipseWhenGlob(tjdStart float64, ifl int, ifltype int, tret []float64, backward int, ...) int32
- func SolEclipseWhenLoc(tjdStart float64, ifl int, geopos []float64, tret []float64, attr []float64, ...) int32
- func SolEclipseWhere(tjd float64, ifl int, geopos []float64, attr []float64, serr []byte) int32
- func Solcross(x2cross float64, jdEt float64, flag int32, serr []byte) float64
- func SolcrossUt(x2cross float64, jdUt float64, flag int32, serr []byte) float64
- func SplitDeg(ddeg float64, roundflag int, ideg []int, imin []int, isec []int, ...)
- func TimeEqu(tjd float64, te []float64, serr []byte) int32
- func TopoArcusVisionis(tjdut float64, dgeo []float64, datm []float64, dobs []float64, helflag int, ...) int32
- func UtcTimeZone(iyear int, imonth int, iday int, ihour int, imin int, dsec float64, ...)
- func UtcToJd(iyear int, imonth int, iday int, ihour int, imin int, dsec float64, ...) int32
- func Version(arg0 []byte) *byte
- func VisLimitMag(tjdut float64, geopos []float64, datm []float64, dobs []float64, ...) int32
- type ASBOOL
- type Centisec
- type Epsilon
- type FILE
- type FileData
- type FixedStar
- type FposT
- type GenConst
- type INT4
- type Int16
- type Int32
- type Int64
- type Interpol
- type Nut
- type PlanData
- type REAL8
- type RawString
- type SavePositions
- type SidData
- type SweData
- type TopoData
- type UCHAR
- type UINT2
- type UINT4
- type Uint32
Constants ¶
const ( // SeAunitToKm as declared in swephexp.h:88 SeAunitToKm = 1.495978707e+08 // SeAunitToLightyear as declared in swephexp.h:89 SeAunitToLightyear = 1.5812507409819728e-05 // SeAunitToParsec as declared in swephexp.h:90 SeAunitToParsec = 4.848136811095274e-06 // SeJulCal as declared in swephexp.h:93 SeJulCal = 0 // SeGregCal as declared in swephexp.h:94 SeGregCal = 1 // SeEclNut as declared in swephexp.h:99 SeEclNut = -1 // SeSun as declared in swephexp.h:101 SeSun = 0 // SeMoon as declared in swephexp.h:102 SeMoon = 1 // SeMercury as declared in swephexp.h:103 SeMercury = 2 // SeVenus as declared in swephexp.h:104 SeVenus = 3 // SeMars as declared in swephexp.h:105 SeMars = 4 // SeJupiter as declared in swephexp.h:106 SeJupiter = 5 // SeSaturn as declared in swephexp.h:107 SeSaturn = 6 // SeUranus as declared in swephexp.h:108 SeUranus = 7 // SeNeptune as declared in swephexp.h:109 SeNeptune = 8 // SePluto as declared in swephexp.h:110 SePluto = 9 // SeMeanNode as declared in swephexp.h:111 SeMeanNode = 10 // SeTrueNode as declared in swephexp.h:112 SeTrueNode = 11 // SeMeanApog as declared in swephexp.h:113 SeMeanApog = 12 // SeOscuApog as declared in swephexp.h:114 SeOscuApog = 13 // SeEarth as declared in swephexp.h:115 SeEarth = 14 // SeChiron as declared in swephexp.h:116 SeChiron = 15 // SePholus as declared in swephexp.h:117 SePholus = 16 // SeCeres as declared in swephexp.h:118 SeCeres = 17 // SePallas as declared in swephexp.h:119 SePallas = 18 // SeJuno as declared in swephexp.h:120 SeJuno = 19 // SeVesta as declared in swephexp.h:121 SeVesta = 20 // SeIntpApog as declared in swephexp.h:122 SeIntpApog = 21 // SeIntpPerg as declared in swephexp.h:123 SeIntpPerg = 22 // SeNplanets as declared in swephexp.h:125 SeNplanets = 23 // SePlmoonOffset as declared in swephexp.h:127 SePlmoonOffset = 9000 // SeAstOffset as declared in swephexp.h:128 SeAstOffset = 10000 // SeVaruna as declared in swephexp.h:129 SeVaruna = 30000 // SeFictOffset as declared in swephexp.h:131 SeFictOffset = 40 // SeFictOffset1 as declared in swephexp.h:132 SeFictOffset1 = 39 // SeFictMax as declared in swephexp.h:133 SeFictMax = 999 // SeNfictElem as declared in swephexp.h:134 SeNfictElem = 15 // SeCometOffset as declared in swephexp.h:136 SeCometOffset = 1000 // SeNallNatPoints as declared in swephexp.h:138 SeNallNatPoints = 38 // SeCupido as declared in swephexp.h:141 SeCupido = 40 // SeHades as declared in swephexp.h:142 SeHades = 41 // SeZeus as declared in swephexp.h:143 SeZeus = 42 // SeKronos as declared in swephexp.h:144 SeKronos = 43 // SeApollon as declared in swephexp.h:145 SeApollon = 44 // SeAdmetos as declared in swephexp.h:146 SeAdmetos = 45 // SeVulkanus as declared in swephexp.h:147 SeVulkanus = 46 // SePoseidon as declared in swephexp.h:148 SePoseidon = 47 // SeIsis as declared in swephexp.h:150 SeIsis = 48 // SeNibiru as declared in swephexp.h:151 SeNibiru = 49 // SeHarrington as declared in swephexp.h:152 SeHarrington = 50 // SeNeptuneLeverrier as declared in swephexp.h:153 SeNeptuneLeverrier = 51 // SeNeptuneAdams as declared in swephexp.h:154 SeNeptuneAdams = 52 // SePlutoLowell as declared in swephexp.h:155 SePlutoLowell = 53 // SePlutoPickering as declared in swephexp.h:156 SePlutoPickering = 54 // SeVulcan as declared in swephexp.h:157 SeVulcan = 55 // SeWhiteMoon as declared in swephexp.h:158 SeWhiteMoon = 56 // SeProserpina as declared in swephexp.h:159 SeProserpina = 57 // SeWaldemath as declared in swephexp.h:160 SeWaldemath = 58 // SeFixstar as declared in swephexp.h:162 SeFixstar = -10 // SeAsc as declared in swephexp.h:164 SeAsc = 0 // SeMc as declared in swephexp.h:165 SeMc = 1 // SeArmc as declared in swephexp.h:166 SeArmc = 2 // SeVertex as declared in swephexp.h:167 SeVertex = 3 // SeEquasc as declared in swephexp.h:168 SeEquasc = 4 // SeCoasc1 as declared in swephexp.h:169 SeCoasc1 = 5 // SeCoasc2 as declared in swephexp.h:170 SeCoasc2 = 6 // SePolasc as declared in swephexp.h:171 SePolasc = 7 // SeNascmc as declared in swephexp.h:172 SeNascmc = 8 // SeflgJpleph as declared in swephexp.h:186 SeflgJpleph = 1 // SeflgSwieph as declared in swephexp.h:187 SeflgSwieph = 2 // SeflgMoseph as declared in swephexp.h:188 SeflgMoseph = 4 // SeflgHelctr as declared in swephexp.h:190 SeflgHelctr = 8 // SeflgTruepos as declared in swephexp.h:191 SeflgTruepos = 16 // SeflgJ2000 as declared in swephexp.h:192 SeflgJ2000 = 32 // SeflgNonut as declared in swephexp.h:193 SeflgNonut = 64 // SeflgSpeed3 as declared in swephexp.h:194 SeflgSpeed3 = 128 // SeflgSpeed as declared in swephexp.h:196 SeflgSpeed = 256 // SeflgNogdefl as declared in swephexp.h:197 SeflgNogdefl = 512 // SeflgNoaberr as declared in swephexp.h:198 SeflgNoaberr = 1024 // SeflgAstrometric as declared in swephexp.h:199 SeflgAstrometric = 1536 // SeflgEquatorial as declared in swephexp.h:202 SeflgEquatorial = 2048 // SeflgXyz as declared in swephexp.h:203 SeflgXyz = 4096 // SeflgRadians as declared in swephexp.h:204 SeflgRadians = 8192 // SeflgBaryctr as declared in swephexp.h:205 SeflgBaryctr = 16384 // SeflgTopoctr as declared in swephexp.h:206 SeflgTopoctr = 32768 // SeflgOrbelAa as declared in swephexp.h:207 SeflgOrbelAa = 32768 // SeflgTropical as declared in swephexp.h:209 SeflgTropical = 0 // SeflgSidereal as declared in swephexp.h:210 SeflgSidereal = 65536 // SeflgIcrs as declared in swephexp.h:211 SeflgIcrs = 131072 // SeflgDpsideps1980 as declared in swephexp.h:212 SeflgDpsideps1980 = 262144 // SeflgJplhor as declared in swephexp.h:214 SeflgJplhor = 262144 // SeflgJplhorApprox as declared in swephexp.h:215 SeflgJplhorApprox = 524288 // SeflgCenterBody as declared in swephexp.h:216 SeflgCenterBody = 1048576 // SeflgTestPlmoon as declared in swephexp.h:218 SeflgTestPlmoon = 2228280 // SeSidbits as declared in swephexp.h:221 SeSidbits = 256 // SeSidbitEclT0 as declared in swephexp.h:223 SeSidbitEclT0 = 256 // SeSidbitSsyPlane as declared in swephexp.h:225 SeSidbitSsyPlane = 512 // SeSidbitUserUt as declared in swephexp.h:227 SeSidbitUserUt = 1024 // SeSidbitEclDate as declared in swephexp.h:230 SeSidbitEclDate = 2048 // SeSidbitNoPrecOffset as declared in swephexp.h:233 SeSidbitNoPrecOffset = 4096 // SeSidbitPrecOrig as declared in swephexp.h:235 SeSidbitPrecOrig = 8192 // SeSidmFaganBradley as declared in swephexp.h:238 SeSidmFaganBradley = 0 // SeSidmLahiri as declared in swephexp.h:239 SeSidmLahiri = 1 // SeSidmDeluce as declared in swephexp.h:240 SeSidmDeluce = 2 // SeSidmRaman as declared in swephexp.h:241 SeSidmRaman = 3 // SeSidmUshashashi as declared in swephexp.h:242 SeSidmUshashashi = 4 // SeSidmKrishnamurti as declared in swephexp.h:243 SeSidmKrishnamurti = 5 // SeSidmDjwhalKhul as declared in swephexp.h:244 SeSidmDjwhalKhul = 6 // SeSidmYukteshwar as declared in swephexp.h:245 SeSidmYukteshwar = 7 // SeSidmJnBhasin as declared in swephexp.h:246 SeSidmJnBhasin = 8 // SeSidmBabylKugler1 as declared in swephexp.h:247 SeSidmBabylKugler1 = 9 // SeSidmBabylKugler2 as declared in swephexp.h:248 SeSidmBabylKugler2 = 10 // SeSidmBabylKugler3 as declared in swephexp.h:249 SeSidmBabylKugler3 = 11 // SeSidmBabylHuber as declared in swephexp.h:250 SeSidmBabylHuber = 12 // SeSidmBabylEtpsc as declared in swephexp.h:251 SeSidmBabylEtpsc = 13 // SeSidmAldebaran15tau as declared in swephexp.h:252 SeSidmAldebaran15tau = 14 // SeSidmHipparchos as declared in swephexp.h:253 SeSidmHipparchos = 15 // SeSidmSassanian as declared in swephexp.h:254 SeSidmSassanian = 16 // SeSidmGalcent0sag as declared in swephexp.h:255 SeSidmGalcent0sag = 17 // SeSidmJ2000 as declared in swephexp.h:256 SeSidmJ2000 = 18 // SeSidmJ1900 as declared in swephexp.h:257 SeSidmJ1900 = 19 // SeSidmB1950 as declared in swephexp.h:258 SeSidmB1950 = 20 // SeSidmSuryasiddhanta as declared in swephexp.h:259 SeSidmSuryasiddhanta = 21 // SeSidmSuryasiddhantaMsun as declared in swephexp.h:260 SeSidmSuryasiddhantaMsun = 22 // SeSidmAryabhata as declared in swephexp.h:261 SeSidmAryabhata = 23 // SeSidmAryabhataMsun as declared in swephexp.h:262 SeSidmAryabhataMsun = 24 // SeSidmSsRevati as declared in swephexp.h:263 SeSidmSsRevati = 25 // SeSidmSsCitra as declared in swephexp.h:264 SeSidmSsCitra = 26 // SeSidmTrueCitra as declared in swephexp.h:265 SeSidmTrueCitra = 27 // SeSidmTrueRevati as declared in swephexp.h:266 SeSidmTrueRevati = 28 // SeSidmTruePushya as declared in swephexp.h:267 SeSidmTruePushya = 29 // SeSidmGalcentRgilbrand as declared in swephexp.h:268 SeSidmGalcentRgilbrand = 30 // SeSidmGalequIau1958 as declared in swephexp.h:269 SeSidmGalequIau1958 = 31 // SeSidmGalequTrue as declared in swephexp.h:270 SeSidmGalequTrue = 32 // SeSidmGalequMula as declared in swephexp.h:271 SeSidmGalequMula = 33 // SeSidmGalalignMardyks as declared in swephexp.h:272 SeSidmGalalignMardyks = 34 // SeSidmTrueMula as declared in swephexp.h:273 SeSidmTrueMula = 35 // SeSidmGalcentMulaWilhelm as declared in swephexp.h:274 SeSidmGalcentMulaWilhelm = 36 // SeSidmAryabhata522 as declared in swephexp.h:275 SeSidmAryabhata522 = 37 // SeSidmBabylBritton as declared in swephexp.h:276 SeSidmBabylBritton = 38 // SeSidmTrueSheoran as declared in swephexp.h:277 SeSidmTrueSheoran = 39 // SeSidmGalcentCochrane as declared in swephexp.h:278 SeSidmGalcentCochrane = 40 // SeSidmGalequFiorenza as declared in swephexp.h:279 SeSidmGalequFiorenza = 41 // SeSidmValensMoon as declared in swephexp.h:280 SeSidmValensMoon = 42 // SeSidmLahiri1940 as declared in swephexp.h:281 SeSidmLahiri1940 = 43 // SeSidmLahiriVp285 as declared in swephexp.h:282 SeSidmLahiriVp285 = 44 // SeSidmKrishnamurtiVp291 as declared in swephexp.h:283 SeSidmKrishnamurtiVp291 = 45 // SeSidmLahiriIcrc as declared in swephexp.h:284 SeSidmLahiriIcrc = 46 // SeSidmUser as declared in swephexp.h:286 SeSidmUser = 255 // SeNsidmPredef as declared in swephexp.h:288 SeNsidmPredef = 47 // SeNodbitMean as declared in swephexp.h:291 SeNodbitMean = 1 // SeNodbitOscu as declared in swephexp.h:292 SeNodbitOscu = 2 // SeNodbitOscuBar as declared in swephexp.h:293 SeNodbitOscuBar = 4 // SeNodbitFopoint as declared in swephexp.h:294 SeNodbitFopoint = 256 // SeflgDefaulteph as declared in swephexp.h:297 SeflgDefaulteph = 2 // SeMaxStname as declared in swephexp.h:299 SeMaxStname = 256 // SeEclCentral as declared in swephexp.h:307 SeEclCentral = 1 // SeEclNoncentral as declared in swephexp.h:308 SeEclNoncentral = 2 // SeEclTotal as declared in swephexp.h:309 SeEclTotal = 4 // SeEclAnnular as declared in swephexp.h:310 SeEclAnnular = 8 // SeEclPartial as declared in swephexp.h:311 SeEclPartial = 16 // SeEclAnnularTotal as declared in swephexp.h:312 SeEclAnnularTotal = 32 // SeEclHybrid as declared in swephexp.h:313 SeEclHybrid = 32 // SeEclPenumbral as declared in swephexp.h:314 SeEclPenumbral = 64 // SeEclAlltypesSolar as declared in swephexp.h:315 SeEclAlltypesSolar = 63 // SeEclAlltypesLunar as declared in swephexp.h:316 SeEclAlltypesLunar = 84 // SeEclVisible as declared in swephexp.h:317 SeEclVisible = 128 // SeEclMaxVisible as declared in swephexp.h:318 SeEclMaxVisible = 256 // SeEcl1stVisible as declared in swephexp.h:319 SeEcl1stVisible = 512 // SeEclPartbegVisible as declared in swephexp.h:320 SeEclPartbegVisible = 512 // SeEcl2ndVisible as declared in swephexp.h:321 SeEcl2ndVisible = 1024 // SeEclTotbegVisible as declared in swephexp.h:322 SeEclTotbegVisible = 1024 // SeEcl3rdVisible as declared in swephexp.h:323 SeEcl3rdVisible = 2048 // SeEclTotendVisible as declared in swephexp.h:324 SeEclTotendVisible = 2048 // SeEcl4thVisible as declared in swephexp.h:325 SeEcl4thVisible = 4096 // SeEclPartendVisible as declared in swephexp.h:326 SeEclPartendVisible = 4096 // SeEclPenumbbegVisible as declared in swephexp.h:327 SeEclPenumbbegVisible = 8192 // SeEclPenumbendVisible as declared in swephexp.h:328 SeEclPenumbendVisible = 16384 // SeEclOccBegDaylight as declared in swephexp.h:329 SeEclOccBegDaylight = 8192 // SeEclOccEndDaylight as declared in swephexp.h:330 SeEclOccEndDaylight = 16384 // SeEclOneTry as declared in swephexp.h:331 SeEclOneTry = 32768 // SeCalcRise as declared in swephexp.h:336 SeCalcRise = 1 // SeCalcSet as declared in swephexp.h:337 SeCalcSet = 2 // SeCalcMtransit as declared in swephexp.h:338 SeCalcMtransit = 4 // SeCalcItransit as declared in swephexp.h:339 SeCalcItransit = 8 // SeBitDiscCenter as declared in swephexp.h:340 SeBitDiscCenter = 256 // SeBitDiscBottom as declared in swephexp.h:343 SeBitDiscBottom = 8192 // SeBitGeoctrNoEclLat as declared in swephexp.h:346 SeBitGeoctrNoEclLat = 128 // SeBitNoRefraction as declared in swephexp.h:349 SeBitNoRefraction = 512 // SeBitCivilTwilight as declared in swephexp.h:351 SeBitCivilTwilight = 1024 // SeBitNauticTwilight as declared in swephexp.h:352 SeBitNauticTwilight = 2048 // SeBitAstroTwilight as declared in swephexp.h:353 SeBitAstroTwilight = 4096 // SeBitFixedDiscSize as declared in swephexp.h:354 SeBitFixedDiscSize = 16384 // SeBitForceSlowMethod as declared in swephexp.h:357 SeBitForceSlowMethod = 32768 // SeBitHinduRising as declared in swephexp.h:361 SeBitHinduRising = 896 // SeEcl2hor as declared in swephexp.h:364 SeEcl2hor = 0 // SeEqu2hor as declared in swephexp.h:365 SeEqu2hor = 1 // SeHor2ecl as declared in swephexp.h:366 SeHor2ecl = 0 // SeHor2equ as declared in swephexp.h:367 SeHor2equ = 1 // SeTrueToApp as declared in swephexp.h:370 SeTrueToApp = 0 // SeAppToTrue as declared in swephexp.h:371 SeAppToTrue = 1 // SeDeNumber as declared in swephexp.h:377 SeDeNumber = 431 // SeFnameDe200 as declared in swephexp.h:378 SeFnameDe200 = "de200.eph" // SeFnameDe403 as declared in swephexp.h:379 SeFnameDe403 = "de403.eph" // SeFnameDe404 as declared in swephexp.h:380 SeFnameDe404 = "de404.eph" // SeFnameDe405 as declared in swephexp.h:381 SeFnameDe405 = "de405.eph" // SeFnameDe406 as declared in swephexp.h:382 SeFnameDe406 = "de406.eph" // SeFnameDe431 as declared in swephexp.h:383 SeFnameDe431 = "de431.eph" // SeFnameDft as declared in swephexp.h:384 SeFnameDft = "de431.eph" // SeFnameDft2 as declared in swephexp.h:385 SeFnameDft2 = "de406.eph" // SeStarfileOld as declared in swephexp.h:386 SeStarfileOld = "fixstars.cat" // SeStarfile as declared in swephexp.h:387 SeStarfile = "sefstars.txt" // SeAstnamfile as declared in swephexp.h:388 SeAstnamfile = "seasnam.txt" // SeFictfile as declared in swephexp.h:389 SeFictfile = "seorbel.txt" // SeEphePath as declared in swephexp.h:403 SeEphePath = ".:/users/ephe2/:/users/ephe/" // SeSplitDegRoundSec as declared in swephexp.h:411 SeSplitDegRoundSec = 1 // SeSplitDegRoundMin as declared in swephexp.h:412 SeSplitDegRoundMin = 2 // SeSplitDegRoundDeg as declared in swephexp.h:413 SeSplitDegRoundDeg = 4 // SeSplitDegZodiacal as declared in swephexp.h:414 SeSplitDegZodiacal = 8 // SeSplitDegNakshatra as declared in swephexp.h:415 SeSplitDegNakshatra = 1024 // SeSplitDegKeepSign as declared in swephexp.h:416 SeSplitDegKeepSign = 16 // SeSplitDegKeepDeg as declared in swephexp.h:419 SeSplitDegKeepDeg = 32 // SeHeliacalRising as declared in swephexp.h:424 SeHeliacalRising = 1 // SeHeliacalSetting as declared in swephexp.h:425 SeHeliacalSetting = 2 // SeMorningFirst as declared in swephexp.h:426 SeMorningFirst = 1 // SeEveningLast as declared in swephexp.h:427 SeEveningLast = 2 // SeEveningFirst as declared in swephexp.h:428 SeEveningFirst = 3 // SeMorningLast as declared in swephexp.h:429 SeMorningLast = 4 // SeAcronychalRising as declared in swephexp.h:430 SeAcronychalRising = 5 // SeAcronychalSetting as declared in swephexp.h:431 SeAcronychalSetting = 6 // SeCosmicalSetting as declared in swephexp.h:432 SeCosmicalSetting = 6 // SeHelflagLongSearch as declared in swephexp.h:434 SeHelflagLongSearch = 128 // SeHelflagHighPrecision as declared in swephexp.h:435 SeHelflagHighPrecision = 256 // SeHelflagOpticalParams as declared in swephexp.h:436 SeHelflagOpticalParams = 512 // SeHelflagNoDetails as declared in swephexp.h:437 SeHelflagNoDetails = 1024 // SeHelflagSearch1Period as declared in swephexp.h:438 SeHelflagSearch1Period = 2048 // SeHelflagVislimDark as declared in swephexp.h:439 SeHelflagVislimDark = 4096 // SeHelflagVislimNomoon as declared in swephexp.h:440 SeHelflagVislimNomoon = 8192 // SeHelflagVislimPhotopic as declared in swephexp.h:442 SeHelflagVislimPhotopic = 16384 // SeHelflagVislimScotopic as declared in swephexp.h:443 SeHelflagVislimScotopic = 32768 // SeHelflagAv as declared in swephexp.h:444 SeHelflagAv = 65536 // SeHelflagAvkindVr as declared in swephexp.h:445 SeHelflagAvkindVr = 65536 // SeHelflagAvkindPto as declared in swephexp.h:446 SeHelflagAvkindPto = 131072 // SeHelflagAvkindMin7 as declared in swephexp.h:447 SeHelflagAvkindMin7 = 262144 // SeHelflagAvkindMin9 as declared in swephexp.h:448 SeHelflagAvkindMin9 = 524288 // SeHelflagAvkind as declared in swephexp.h:449 SeHelflagAvkind = 983040 // TjdInvalid as declared in swephexp.h:450 TjdInvalid = 9.9999999e+07 // SimulateVictorvb as declared in swephexp.h:451 SimulateVictorvb = 1 // SePhotopicFlag as declared in swephexp.h:469 SePhotopicFlag = 0 // SeScotopicFlag as declared in swephexp.h:470 SeScotopicFlag = 1 // SeMixedopicFlag as declared in swephexp.h:471 SeMixedopicFlag = 2 // SeTidalDe200 as declared in swephexp.h:478 SeTidalDe200 = -23.8946 // SeTidalDe403 as declared in swephexp.h:479 SeTidalDe403 = -25.58 // SeTidalDe404 as declared in swephexp.h:480 SeTidalDe404 = -25.58 // SeTidalDe405 as declared in swephexp.h:481 SeTidalDe405 = -25.826 // SeTidalDe406 as declared in swephexp.h:482 SeTidalDe406 = -25.826 // SeTidalDe421 as declared in swephexp.h:483 SeTidalDe421 = -25.85 // SeTidalDe422 as declared in swephexp.h:484 SeTidalDe422 = -25.85 // SeTidalDe430 as declared in swephexp.h:485 SeTidalDe430 = -25.82 // SeTidalDe431 as declared in swephexp.h:486 SeTidalDe431 = -25.8 // SeTidalDe441 as declared in swephexp.h:487 SeTidalDe441 = -25.936 // SeTidal26 as declared in swephexp.h:488 SeTidal26 = -26 // SeTidalStephenson2016 as declared in swephexp.h:489 SeTidalStephenson2016 = -25.85 // SeTidalDefault as declared in swephexp.h:490 SeTidalDefault = -25.8 // SeTidalAutomatic as declared in swephexp.h:491 SeTidalAutomatic = 999999 // SeTidalMoseph as declared in swephexp.h:492 SeTidalMoseph = -25.58 // SeTidalSwieph as declared in swephexp.h:493 SeTidalSwieph = -25.8 // SeTidalJpleph as declared in swephexp.h:494 SeTidalJpleph = -25.8 // SeDeltatAutomatic as declared in swephexp.h:497 SeDeltatAutomatic = -1e-10 // SeModelDeltat as declared in swephexp.h:499 SeModelDeltat = 0 // SeModelPrecLongterm as declared in swephexp.h:500 SeModelPrecLongterm = 1 // SeModelPrecShortterm as declared in swephexp.h:501 SeModelPrecShortterm = 2 // SeModelNut as declared in swephexp.h:502 SeModelNut = 3 // SeModelBias as declared in swephexp.h:503 SeModelBias = 4 // SeModelJplhorMode as declared in swephexp.h:504 SeModelJplhorMode = 5 // SeModelJplhoraMode as declared in swephexp.h:505 SeModelJplhoraMode = 6 // SeModelSidt as declared in swephexp.h:506 SeModelSidt = 7 // NseModels as declared in swephexp.h:507 NseModels = 8 // SemodNprec as declared in swephexp.h:510 SemodNprec = 11 // SemodPrecIau1976 as declared in swephexp.h:511 SemodPrecIau1976 = 1 // SemodPrecLaskar1986 as declared in swephexp.h:512 SemodPrecLaskar1986 = 2 // SemodPrecWillEpsLask as declared in swephexp.h:513 SemodPrecWillEpsLask = 3 // SemodPrecWilliams1994 as declared in swephexp.h:514 SemodPrecWilliams1994 = 4 // SemodPrecSimon1994 as declared in swephexp.h:515 SemodPrecSimon1994 = 5 // SemodPrecIau2000 as declared in swephexp.h:516 SemodPrecIau2000 = 6 // SemodPrecBretagnon2003 as declared in swephexp.h:517 SemodPrecBretagnon2003 = 7 // SemodPrecIau2006 as declared in swephexp.h:518 SemodPrecIau2006 = 8 // SemodPrecVondrak2011 as declared in swephexp.h:519 SemodPrecVondrak2011 = 9 // SemodPrecOwen1990 as declared in swephexp.h:520 SemodPrecOwen1990 = 10 // SemodPrecNewcomb as declared in swephexp.h:521 SemodPrecNewcomb = 11 // SemodPrecDefault as declared in swephexp.h:522 SemodPrecDefault = 9 // SemodPrecDefaultShort as declared in swephexp.h:527 SemodPrecDefaultShort = 9 // SemodNnut as declared in swephexp.h:530 SemodNnut = 5 // SemodNutIau1980 as declared in swephexp.h:531 SemodNutIau1980 = 1 // SemodNutIauCorr1987 as declared in swephexp.h:532 SemodNutIauCorr1987 = 2 // SemodNutIau2000a as declared in swephexp.h:534 SemodNutIau2000a = 3 // SemodNutIau2000b as declared in swephexp.h:535 SemodNutIau2000b = 4 // SemodNutWoolard as declared in swephexp.h:536 SemodNutWoolard = 5 // SemodNutDefault as declared in swephexp.h:537 SemodNutDefault = 4 // SemodNsidt as declared in swephexp.h:540 SemodNsidt = 4 // SemodSidtIau1976 as declared in swephexp.h:541 SemodSidtIau1976 = 1 // SemodSidtIau2006 as declared in swephexp.h:542 SemodSidtIau2006 = 2 // SemodSidtIersConv2010 as declared in swephexp.h:543 SemodSidtIersConv2010 = 3 // SemodSidtLongterm as declared in swephexp.h:544 SemodSidtLongterm = 4 // SemodSidtDefault as declared in swephexp.h:545 SemodSidtDefault = 4 // SemodNbias as declared in swephexp.h:549 SemodNbias = 3 // SemodBiasNone as declared in swephexp.h:550 SemodBiasNone = 1 // SemodBiasIau2000 as declared in swephexp.h:551 SemodBiasIau2000 = 2 // SemodBiasIau2006 as declared in swephexp.h:552 SemodBiasIau2006 = 3 // SemodBiasDefault as declared in swephexp.h:553 SemodBiasDefault = 3 // SemodNjplhor as declared in swephexp.h:557 SemodNjplhor = 2 // SemodJplhorLongAgreement as declared in swephexp.h:558 SemodJplhorLongAgreement = 1 // SemodJplhorDefault as declared in swephexp.h:562 SemodJplhorDefault = 1 // SemodNjplhora as declared in swephexp.h:577 SemodNjplhora = 3 // SemodJplhora1 as declared in swephexp.h:578 SemodJplhora1 = 1 // SemodJplhora2 as declared in swephexp.h:579 SemodJplhora2 = 2 // SemodJplhora3 as declared in swephexp.h:580 SemodJplhora3 = 3 // SemodJplhoraDefault as declared in swephexp.h:581 SemodJplhoraDefault = 3 // SemodNdeltat as declared in swephexp.h:599 SemodNdeltat = 5 // SemodDeltatStephensonMorrison1984 as declared in swephexp.h:600 SemodDeltatStephensonMorrison1984 = 1 // SemodDeltatStephenson1997 as declared in swephexp.h:601 SemodDeltatStephenson1997 = 2 // SemodDeltatStephensonMorrison2004 as declared in swephexp.h:602 SemodDeltatStephensonMorrison2004 = 3 // SemodDeltatEspenakMeeus2006 as declared in swephexp.h:603 SemodDeltatEspenakMeeus2006 = 4 // SemodDeltatStephensonEtc2016 as declared in swephexp.h:604 SemodDeltatStephensonEtc2016 = 5 // SemodDeltatDefault as declared in swephexp.h:606 SemodDeltatDefault = 5 // Malloc as declared in swephexp.h:638 Malloc = 0 // Calloc as declared in swephexp.h:639 Calloc = 0 // Free as declared in swephexp.h:640 Free = 0 // MyTrue as defined in sweodef.h:74 MyTrue = 1 // MyFalse as defined in sweodef.h:75 MyFalse = 0 // Tls as defined in sweodef.h:84 Tls = 0 // Msdos as defined in sweodef.h:157 Msdos = 0 // Hpunix as defined in sweodef.h:158 Hpunix = 1 // UnixFs as defined in sweodef.h:162 UnixFs = 1 // Abs4 as defined in sweodef.h:220 Abs4 = 0 // True as defined in sweodef.h:233 True = 1 // False as defined in sweodef.h:234 False = 0 // Ok as defined in sweodef.h:238 Ok = 0 // Err as defined in sweodef.h:239 Err = -1 // Ucp as defined in sweodef.h:250 //Ucp = ( UCHAR * )( ) // OdegreeString as defined in sweodef.h:253 OdegreeString = "°" // AsMaxch as defined in sweodef.h:266 AsMaxch = 256 // Radtodeg as defined in sweodef.h:272 Radtodeg = 57.29577951308232 // Degtorad as defined in sweodef.h:273 Degtorad = 0.017453292519943295 // Cs as defined in sweodef.h:276 Cs = 0 // Csec as defined in sweodef.h:277 Csec = 0 // Deg as defined in sweodef.h:279 Deg = 360000 // Deg730 as defined in sweodef.h:280 Deg730 = 2700000 // Deg15 as defined in sweodef.h:281 Deg15 = 5400000 // Deg24 as defined in sweodef.h:282 Deg24 = 8640000 // Deg30 as defined in sweodef.h:283 Deg30 = 10800000 // Deg60 as defined in sweodef.h:284 Deg60 = 21600000 // Deg90 as defined in sweodef.h:285 Deg90 = 32400000 // Deg120 as defined in sweodef.h:286 Deg120 = 43200000 // Deg150 as defined in sweodef.h:287 Deg150 = 54000000 // Deg180 as defined in sweodef.h:288 Deg180 = 64800000 // Deg270 as defined in sweodef.h:289 Deg270 = 97200000 // Deg360 as defined in sweodef.h:290 Deg360 = 129600000 // Cstorad as defined in sweodef.h:294 Cstorad = 4.84813681109536e-08 // Radtocs as defined in sweodef.h:295 Radtocs = 2.0626480624709636e+07 // Cs2deg as defined in sweodef.h:297 Cs2deg = 2.777777777777778e-06 // BfileRAccess as defined in sweodef.h:301 BfileRAccess = "r" // BfileRwAccess as defined in sweodef.h:302 BfileRwAccess = "r+" // BfileWCreate as defined in sweodef.h:303 BfileWCreate = "w" // BfileAAccess as defined in sweodef.h:304 BfileAAccess = "a+" // FileRAccess as defined in sweodef.h:305 FileRAccess = "r" // FileRwAccess as defined in sweodef.h:306 FileRwAccess = "r+" // FileWCreate as defined in sweodef.h:307 FileWCreate = "w" // FileAAccess as defined in sweodef.h:308 FileAAccess = "a+" // OBinary as defined in sweodef.h:309 OBinary = 0 // OpenMode as defined in sweodef.h:310 OpenMode = 438 // DirGlue as defined in sweodef.h:311 DirGlue = "/" // PathSeparator as defined in sweodef.h:312 PathSeparator = ";:" // SeVersion as defined in sweph.h:65 SeVersion = "2.10.03" // J2000 as defined in sweph.h:67 J2000 = 2.451545e+06 // B1950 as defined in sweph.h:68 B1950 = 2.43328242345905e+06 // J1900 as defined in sweph.h:69 J1900 = 2.41502e+06 // B1850 as defined in sweph.h:70 B1850 = 2.396758203581e+06 // MpcCeres as defined in sweph.h:72 MpcCeres = 1 // MpcPallas as defined in sweph.h:73 MpcPallas = 2 // MpcJuno as defined in sweph.h:74 MpcJuno = 3 // MpcVesta as defined in sweph.h:75 MpcVesta = 4 // MpcChiron as defined in sweph.h:76 MpcChiron = 2060 // MpcPholus as defined in sweph.h:77 MpcPholus = 5145 // SeNameSun as defined in sweph.h:79 SeNameSun = "Sun" // SeNameMoon as defined in sweph.h:80 SeNameMoon = "Moon" // SeNameMercury as defined in sweph.h:81 SeNameMercury = "Mercury" // SeNameVenus as defined in sweph.h:82 SeNameVenus = "Venus" // SeNameMars as defined in sweph.h:83 SeNameMars = "Mars" // SeNameJupiter as defined in sweph.h:84 SeNameJupiter = "Jupiter" // SeNameSaturn as defined in sweph.h:85 SeNameSaturn = "Saturn" // SeNameUranus as defined in sweph.h:86 SeNameUranus = "Uranus" // SeNameNeptune as defined in sweph.h:87 SeNameNeptune = "Neptune" // SeNamePluto as defined in sweph.h:88 SeNamePluto = "Pluto" // SeNameMeanNode as defined in sweph.h:89 SeNameMeanNode = "mean Node" // SeNameTrueNode as defined in sweph.h:90 SeNameTrueNode = "true Node" // SeNameMeanApog as defined in sweph.h:91 SeNameMeanApog = "mean Apogee" // SeNameOscuApog as defined in sweph.h:92 SeNameOscuApog = "osc. Apogee" // SeNameIntpApog as defined in sweph.h:93 SeNameIntpApog = "intp. Apogee" // SeNameIntpPerg as defined in sweph.h:94 SeNameIntpPerg = "intp. Perigee" // SeNameEarth as defined in sweph.h:95 SeNameEarth = "Earth" // SeNameCeres as defined in sweph.h:96 SeNameCeres = "Ceres" // SeNamePallas as defined in sweph.h:97 SeNamePallas = "Pallas" // SeNameJuno as defined in sweph.h:98 SeNameJuno = "Juno" // SeNameVesta as defined in sweph.h:99 SeNameVesta = "Vesta" // SeNameChiron as defined in sweph.h:100 SeNameChiron = "Chiron" // SeNamePholus as defined in sweph.h:101 SeNamePholus = "Pholus" // SeNameCupido as defined in sweph.h:104 SeNameCupido = "Cupido" // SeNameHades as defined in sweph.h:105 SeNameHades = "Hades" // SeNameZeus as defined in sweph.h:106 SeNameZeus = "Zeus" // SeNameKronos as defined in sweph.h:107 SeNameKronos = "Kronos" // SeNameApollon as defined in sweph.h:108 SeNameApollon = "Apollon" // SeNameAdmetos as defined in sweph.h:109 SeNameAdmetos = "Admetos" // SeNameVulkanus as defined in sweph.h:110 SeNameVulkanus = "Vulkanus" // SeNamePoseidon as defined in sweph.h:111 SeNamePoseidon = "Poseidon" // SeNameIsis as defined in sweph.h:112 SeNameIsis = "Isis" // SeNameNibiru as defined in sweph.h:113 SeNameNibiru = "Nibiru" // SeNameHarrington as defined in sweph.h:114 SeNameHarrington = "Harrington" // SeNameNeptuneLeverrier as defined in sweph.h:115 SeNameNeptuneLeverrier = "Leverrier" // SeNameNeptuneAdams as defined in sweph.h:116 SeNameNeptuneAdams = "Adams" // SeNamePlutoLowell as defined in sweph.h:117 SeNamePlutoLowell = "Lowell" // SeNamePlutoPickering as defined in sweph.h:118 SeNamePlutoPickering = "Pickering" // SeNameVulcan as defined in sweph.h:119 SeNameVulcan = "Vulcan" // SeNameWhiteMoon as defined in sweph.h:120 SeNameWhiteMoon = "White Moon" // Pi as defined in sweph.h:126 Pi = 3.141592653589793 // Twopi as defined in sweph.h:127 Twopi = 6.283185307179586 // Endmark as defined in sweph.h:129 Endmark = -99 // SeiEpsilon as defined in sweph.h:131 SeiEpsilon = -2 // SeiNutation as defined in sweph.h:132 SeiNutation = -1 // SeiEmb as defined in sweph.h:133 SeiEmb = 0 // SeiEarth as defined in sweph.h:134 SeiEarth = 0 // SeiSun as defined in sweph.h:135 SeiSun = 0 // SeiMoon as defined in sweph.h:136 SeiMoon = 1 // SeiMercury as defined in sweph.h:137 SeiMercury = 2 // SeiVenus as defined in sweph.h:138 SeiVenus = 3 // SeiMars as defined in sweph.h:139 SeiMars = 4 // SeiJupiter as defined in sweph.h:140 SeiJupiter = 5 // SeiSaturn as defined in sweph.h:141 SeiSaturn = 6 // SeiUranus as defined in sweph.h:142 SeiUranus = 7 // SeiNeptune as defined in sweph.h:143 SeiNeptune = 8 // SeiPluto as defined in sweph.h:144 SeiPluto = 9 // SeiSunbary as defined in sweph.h:145 SeiSunbary = 10 // SeiAnybody as defined in sweph.h:146 SeiAnybody = 11 // SeiChiron as defined in sweph.h:147 SeiChiron = 12 // SeiPholus as defined in sweph.h:148 SeiPholus = 13 // SeiCeres as defined in sweph.h:149 SeiCeres = 14 // SeiPallas as defined in sweph.h:150 SeiPallas = 15 // SeiJuno as defined in sweph.h:151 SeiJuno = 16 // SeiVesta as defined in sweph.h:152 SeiVesta = 17 // SeiNplanets as defined in sweph.h:154 SeiNplanets = 18 // SeiMeanNode as defined in sweph.h:156 SeiMeanNode = 0 // SeiTrueNode as defined in sweph.h:157 SeiTrueNode = 1 // SeiMeanApog as defined in sweph.h:158 SeiMeanApog = 2 // SeiOscuApog as defined in sweph.h:159 SeiOscuApog = 3 // SeiIntpApog as defined in sweph.h:160 SeiIntpApog = 4 // SeiIntpPerg as defined in sweph.h:161 SeiIntpPerg = 5 // SeiNnodeEtc as defined in sweph.h:163 SeiNnodeEtc = 6 // SeiFlgHelio as defined in sweph.h:165 SeiFlgHelio = 1 // SeiFlgRotate as defined in sweph.h:166 SeiFlgRotate = 2 // SeiFlgEllipse as defined in sweph.h:167 SeiFlgEllipse = 4 // SeiFlgEmbhel as defined in sweph.h:168 SeiFlgEmbhel = 8 // SeiFilePlanet as defined in sweph.h:173 SeiFilePlanet = 0 // SeiFileMoon as defined in sweph.h:174 SeiFileMoon = 1 // SeiFileMainAst as defined in sweph.h:175 SeiFileMainAst = 2 // SeiFileAnyAst as defined in sweph.h:176 SeiFileAnyAst = 3 // SeiFileFixstar as defined in sweph.h:177 SeiFileFixstar = 4 // SeiFilePlmoon as defined in sweph.h:178 SeiFilePlmoon = 5 // SeiFileTestEndian as defined in sweph.h:183 SeiFileTestEndian = 6382179 // SeiFileBigendian as defined in sweph.h:184 SeiFileBigendian = 0 // SeiFileNoreord as defined in sweph.h:185 SeiFileNoreord = 0 // SeiFileLitendian as defined in sweph.h:186 SeiFileLitendian = 1 // SeiFileReord as defined in sweph.h:187 SeiFileReord = 2 // SeiFileNmaxplan as defined in sweph.h:189 SeiFileNmaxplan = 50 // SeiFileEfposbegin as defined in sweph.h:190 SeiFileEfposbegin = 500 // SeFileSuffix as defined in sweph.h:192 SeFileSuffix = "se1" // SeiNephfiles as defined in sweph.h:194 SeiNephfiles = 7 // SeiCurrFpos as defined in sweph.h:195 SeiCurrFpos = -1 // SeiNmodels as defined in sweph.h:196 SeiNmodels = 8 // SeiEclGeoaltMax as defined in sweph.h:198 SeiEclGeoaltMax = 25000 // SeiEclGeoaltMin as defined in sweph.h:199 SeiEclGeoaltMin = -500 // ChironStart as defined in sweph.h:207 ChironStart = 1.9676015e+06 // ChironEnd as defined in sweph.h:208 ChironEnd = 3.4194375e+06 // PholusStart as defined in sweph.h:216 PholusStart = 640648.5 // PholusEnd as defined in sweph.h:217 PholusEnd = 4.3906175e+06 // MoshplephStart as defined in sweph.h:219 MoshplephStart = 625000.5 // MoshplephEnd as defined in sweph.h:220 MoshplephEnd = 2.8180005e+06 // MoshluephStart as defined in sweph.h:221 MoshluephStart = 625000.5 // MoshluephEnd as defined in sweph.h:222 MoshluephEnd = 2.8180005e+06 // MoshndephStart as defined in sweph.h:225 MoshndephStart = -3.1000155e+06 // MoshndephEnd as defined in sweph.h:226 MoshndephEnd = 8.0000165e+06 // JplDe431Start as defined in sweph.h:233 JplDe431Start = -3.0272155e+06 // JplDe431End as defined in sweph.h:234 JplDe431End = 7.9301925e+06 // Maxord as defined in sweph.h:247 Maxord = 40 // Ncties as defined in sweph.h:249 Ncties = 6 // NotAvailable as defined in sweph.h:253 NotAvailable = -2 // BeyondEphLimits as defined in sweph.h:254 BeyondEphLimits = -3 // JToJ2000 as defined in sweph.h:256 JToJ2000 = 1 // J2000ToJ as defined in sweph.h:257 J2000ToJ = -1 // MoonMeanDist as defined in sweph.h:260 MoonMeanDist = 3.844e+08 // MoonMeanIncl as defined in sweph.h:261 MoonMeanIncl = 5.1453964 // MoonMeanEcc as defined in sweph.h:262 MoonMeanEcc = 0.054900489 // SunEarthMrat as defined in sweph.h:264 SunEarthMrat = 332946.050895 // EarthMoonMrat as defined in sweph.h:265 EarthMoonMrat = 81.30055985272827 // Aunit as defined in sweph.h:273 Aunit = 1.495978707e+11 // Clight as defined in sweph.h:274 Clight = 2.99792458e+08 // Helgravconst as defined in sweph.h:278 Helgravconst = 1.32712440017987e+20 // Geogconst as defined in sweph.h:279 Geogconst = 3.98600448e+14 // Kgauss as defined in sweph.h:280 Kgauss = 0.01720209895 // SunRadius as defined in sweph.h:281 SunRadius = 0.00465241752803144 // EarthRadius as defined in sweph.h:282 EarthRadius = 6.3781366e+06 // EarthOblateness as defined in sweph.h:284 EarthOblateness = 0.003352819697896193 // EarthRotSpeed as defined in sweph.h:285 EarthRotSpeed = 6.300387486748799 // LighttimeAunit as defined in sweph.h:287 LighttimeAunit = 0.005775518331437499 // ParsecToAunit as defined in sweph.h:288 ParsecToAunit = 206264.8062471 // SsyPlaneNodeE2000 as defined in sweph.h:291 SsyPlaneNodeE2000 = 1.8776700468039835 // SsyPlaneNode as defined in sweph.h:293 SsyPlaneNode = 1.8777793895872257 // SsyPlaneIncl as defined in sweph.h:295 SsyPlaneIncl = 0.027553530354526998 // KmSToAuCty as defined in sweph.h:297 KmSToAuCty = 21.095 // MoonSpeedIntv as defined in sweph.h:298 MoonSpeedIntv = 5e-05 // PlanSpeedIntv as defined in sweph.h:299 PlanSpeedIntv = 0.0001 // MeanNodeSpeedIntv as defined in sweph.h:300 MeanNodeSpeedIntv = 0.001 // NodeCalcIntv as defined in sweph.h:301 NodeCalcIntv = 0.0001 // NodeCalcIntvMosh as defined in sweph.h:302 NodeCalcIntvMosh = 0.1 // NutSpeedIntv as defined in sweph.h:303 NutSpeedIntv = 0.0001 // DeflSpeedIntv as defined in sweph.h:304 DeflSpeedIntv = 5e-07 // SeLapseRate as defined in sweph.h:306 SeLapseRate = 0.0065 // Ndiam as defined in sweph.h:314 Ndiam = 21 // Str as defined in sweph.h:666 Str = 4.84813681109536e-06 // SwiStarLength as defined in sweph.h:775 SwiStarLength = 40 // SweDataDpsiDeps as defined in sweph.h:785 SweDataDpsiDeps = 36525 )
Variables ¶
This section is empty.
Functions ¶
func Azalt ¶
func Azalt(tjdUt float64, calcFlag int, geopos []float64, atpress float64, attemp float64, xin []float64, xaz []float64)
Azalt function as declared in swephexp.h:893
func Cs2lonlatstr ¶
Cs2lonlatstr function as declared in swephexp.h:1010
func Cs2timestr ¶
Cs2timestr function as declared in swephexp.h:1008
func DateConversion ¶
DateConversion function as declared in swephexp.h:771
func Fixstar2Mag ¶
Fixstar2Mag function as declared in swephexp.h:735
func Fixstar2Ut ¶
Fixstar2Ut function as declared in swephexp.h:732
func FixstarMag ¶
FixstarMag function as declared in swephexp.h:725
func GauquelinSector ¶
func GauquelinSector(tUt float64, ipl int, starname []byte, iflag int, imeth int, geopos []float64, atpress float64, attemp float64, dgsect []float64, serr []byte) int32
GauquelinSector function as declared in swephexp.h:843
func GetAstroModels ¶
GetAstroModels function as declared in swephexp.h:687
func GetAyanamsa ¶
GetAyanamsa function as declared in swephexp.h:758
func GetAyanamsaEx ¶
GetAyanamsaEx function as declared in swephexp.h:756
func GetAyanamsaExUt ¶
GetAyanamsaExUt function as declared in swephexp.h:757
func GetAyanamsaName ¶
GetAyanamsaName function as declared in swephexp.h:762
func GetAyanamsaUt ¶
GetAyanamsaUt function as declared in swephexp.h:759
func GetCurrentFileData ¶
GetCurrentFileData function as declared in swephexp.h:763
func GetLibraryPath ¶
GetLibraryPath function as declared in swephexp.h:694
func GetOrbitalElements ¶
GetOrbitalElements function as declared in swephexp.h:937
func GetPlanetName ¶
GetPlanetName function as declared in swephexp.h:747
func HeliacalAngle ¶
func HeliacalAngle(tjdut float64, dgeo []float64, datm []float64, dobs []float64, helflag int, mag float64, aziObj float64, aziSun float64, aziMoon float64, altMoon float64, dret []float64, serr []byte) int32
HeliacalAngle function as declared in swephexp.h:681
func HeliacalPhenoUt ¶
func HeliacalPhenoUt(tjdUt float64, geopos []float64, datm []float64, dobs []float64, objectName []byte, typeEvent int, helflag int, darr []float64, serr []byte) int32
HeliacalPhenoUt function as declared in swephexp.h:677
func HeliacalUt ¶
func HeliacalUt(tjdstartUt float64, geopos []float64, datm []float64, dobs []float64, objectName []byte, typeEvent int, iflag int, dret []float64, serr []byte) int32
HeliacalUt function as declared in swephexp.h:676
func HelioCross ¶
func HelioCross(ipl int32, x2cross float64, jdEt float64, iflag int32, dir int32, jdCross []float64, serr []byte) int32
HelioCross function as declared in swephexp.h:713
func HelioCrossUt ¶
func HelioCrossUt(ipl int32, x2cross float64, jdUt float64, iflag int32, dir int32, jdCross []float64, serr []byte) int32
HelioCrossUt function as declared in swephexp.h:714
func HousePos ¶
func HousePos(armc float64, geolat float64, eps float64, hsys int, xpin []float64, serr []byte) float64
HousePos function as declared in swephexp.h:832
func Houses ¶
func Houses(tjdUt float64, geolat float64, geolon float64, hsys int, cusps []float64, ascmc []float64) int32
Houses function as declared in swephexp.h:812
func HousesArmc ¶
func HousesArmc(armc float64, geolat float64, eps float64, hsys int, cusps []float64, ascmc []float64) int32
HousesArmc function as declared in swephexp.h:824
func HousesArmcEx2 ¶
func HousesArmcEx2(armc float64, geolat float64, eps float64, hsys int, cusps []float64, ascmc []float64, cuspSpeed []float64, ascmcSpeed []float64, serr []byte) int32
HousesArmcEx2 function as declared in swephexp.h:828
func HousesEx ¶
func HousesEx(tjdUt float64, iflag int, geolat float64, geolon float64, hsys int, cusps []float64, ascmc []float64) int32
HousesEx function as declared in swephexp.h:816
func HousesEx2 ¶
func HousesEx2(tjdUt float64, iflag int, geolat float64, geolon float64, hsys int, cusps []float64, ascmc []float64, cuspSpeed []float64, ascmcSpeed []float64, serr []byte) int32
HousesEx2 function as declared in swephexp.h:820
func JdetToUtc ¶
func JdetToUtc(tjdEt float64, gregflag int, iyear []int, imonth []int, iday []int, ihour []int, imin []int, dsec []float64)
JdetToUtc function as declared in swephexp.h:791
func Jdut1ToUtc ¶
func Jdut1ToUtc(tjdUt float64, gregflag int, iyear []int, imonth []int, iday []int, ihour []int, imin []int, dsec []float64)
Jdut1ToUtc function as declared in swephexp.h:796
func LunEclipseHow ¶
LunEclipseHow function as declared in swephexp.h:869
func LunEclipseWhen ¶
func LunEclipseWhen(tjdStart float64, ifl int, ifltype int, tret []float64, backward int, serr []byte) int32
LunEclipseWhen function as declared in swephexp.h:876
func LunEclipseWhenLoc ¶
func LunEclipseWhenLoc(tjdStart float64, ifl int, geopos []float64, tret []float64, attr []float64, backward int, serr []byte) int32
LunEclipseWhenLoc function as declared in swephexp.h:879
func LunOccultWhenGlob ¶
func LunOccultWhenGlob(tjdStart float64, ipl int, starname []byte, ifl int, ifltype int, tret []float64, backward int, serr []byte) int32
LunOccultWhenGlob function as declared in swephexp.h:865
func LunOccultWhenLoc ¶
func LunOccultWhenLoc(tjdStart float64, ipl int, starname []byte, ifl int, geopos []float64, tret []float64, attr []float64, backward int, serr []byte) int32
LunOccultWhenLoc function as declared in swephexp.h:857
func LunOccultWhere ¶
func LunOccultWhere(tjd float64, ipl int, starname []byte, ifl int, geopos []float64, attr []float64, serr []byte) int32
LunOccultWhere function as declared in swephexp.h:849
func MooncrossNode ¶
MooncrossNode function as declared in swephexp.h:711
func MooncrossNodeUt ¶
MooncrossNodeUt function as declared in swephexp.h:712
func MooncrossUt ¶
MooncrossUt function as declared in swephexp.h:710
func NodAps ¶
func NodAps(tjdEt float64, ipl int, iflag int, method int, xnasc []float64, xndsc []float64, xperi []float64, xaphe []float64, serr []byte) int32
NodAps function as declared in swephexp.h:926
func NodApsUt ¶
func NodApsUt(tjdUt float64, ipl int, iflag int, method int, xnasc []float64, xndsc []float64, xperi []float64, xaphe []float64, serr []byte) int32
NodApsUt function as declared in swephexp.h:932
func OrbitMaxMinTrueDistance ¶
func OrbitMaxMinTrueDistance(tjdEt float64, ipl int, iflag int, dmax []float64, dmin []float64, dtrue []float64, serr []byte) int32
OrbitMaxMinTrueDistance function as declared in swephexp.h:940
func RefracExtended ¶
func RefracExtended(inalt float64, geoalt float64, atpress float64, attemp float64, lapseRate float64, calcFlag int, dret []float64) float64
RefracExtended function as declared in swephexp.h:889
func RiseTrans ¶
func RiseTrans(tjdUt float64, ipl int, starname []byte, epheflag int, rsmi int, geopos []float64, atpress float64, attemp float64, tret []float64, serr []byte) int32
RiseTrans function as declared in swephexp.h:918
func RiseTransTrueHor ¶
func RiseTransTrueHor(tjdUt float64, ipl int, starname []byte, epheflag int, rsmi int, geopos []float64, atpress float64, attemp float64, horhgt float64, tret []float64, serr []byte) int32
RiseTransTrueHor function as declared in swephexp.h:909
func SetAstroModels ¶
SetAstroModels function as declared in swephexp.h:686
func SetDeltaTUserdef ¶
func SetDeltaTUserdef(dt float64)
SetDeltaTUserdef function as declared in swephexp.h:970
func SetInterpolateNut ¶
func SetInterpolateNut(doInterpolate int32)
SetInterpolateNut function as declared in swephexp.h:958
func SetLapseRate ¶
func SetLapseRate(lapseRate float64)
SetLapseRate function as declared in swephexp.h:891
func SetSidMode ¶
SetSidMode function as declared in swephexp.h:753
func SolEclipseHow ¶
SolEclipseHow function as declared in swephexp.h:852
func SolEclipseWhenGlob ¶
func SolEclipseWhenGlob(tjdStart float64, ifl int, ifltype int, tret []float64, backward int, serr []byte) int32
SolEclipseWhenGlob function as declared in swephexp.h:861
func SolEclipseWhenLoc ¶
func SolEclipseWhenLoc(tjdStart float64, ifl int, geopos []float64, tret []float64, attr []float64, backward int, serr []byte) int32
SolEclipseWhenLoc function as declared in swephexp.h:855
func SolEclipseWhere ¶
SolEclipseWhere function as declared in swephexp.h:847
func SolcrossUt ¶
SolcrossUt function as declared in swephexp.h:708
func SplitDeg ¶
func SplitDeg(ddeg float64, roundflag int, ideg []int, imin []int, isec []int, dsecfr []float64, isgn []int32)
SplitDeg function as declared in swephexp.h:977
func TopoArcusVisionis ¶
func TopoArcusVisionis(tjdut float64, dgeo []float64, datm []float64, dobs []float64, helflag int, mag float64, aziObj float64, altObj float64, aziSun float64, aziMoon float64, altMoon float64, dret []float64, serr []byte) int32
TopoArcusVisionis function as declared in swephexp.h:682
func UtcTimeZone ¶
func UtcTimeZone(iyear int, imonth int, iday int, ihour int, imin int, dsec float64, dTimezone float64, iyearOut []int, imonthOut []int, idayOut []int, ihourOut []int, iminOut []int, dsecOut []float64)
UtcTimeZone function as declared in swephexp.h:801
Types ¶
type Epsilon ¶
type Epsilon struct {
Teps float64
Eps float64
Seps float64
Ceps float64
// contains filtered or unexported fields
}
Epsilon as declared in sweph.h:837
type FILE ¶
type FILE struct {
P []byte
R int32
W int32
Flags int16
File int16
Bf _Sbuf
Lbfsize int32
Cookie unsafe.Pointer
Close *func(arg0 unsafe.Pointer) int32
Read *func(arg0 unsafe.Pointer, arg1 []byte, arg2 int32) int32
Seek FposT
Write *func(arg0 unsafe.Pointer, arg1 []string, arg2 int32) int32
Ub _Sbuf
Extra []_SFILEX
Ur int32
Ubuf [3]byte
Nbuf [1]byte
Lb _Sbuf
Blksize int32
Offset FposT
// contains filtered or unexported fields
}
FILE as declared in include/_stdio.h:157
type FileData ¶
type FileData struct {
Fnam [256]byte
Fversion int32
Astnam [50]byte
SwephDenum int32
Fptr []FILE
Tfstart float64
Tfend float64
Iflg int32
Npl int16
Ipl [50]int32
// contains filtered or unexported fields
}
FileData as declared in sweph.h:827
type FixedStar ¶
type FixedStar struct {
Skey [42]byte
Starname [41]byte
Starbayer [41]byte
Starno [10]byte
Epoch float64
Ra float64
De float64
Ramot float64
Demot float64
Radvel float64
Parall float64
Mag float64
// contains filtered or unexported fields
}
FixedStar as declared in sweph.h:846
type GenConst ¶
type GenConst struct {
Clight float64
Aunit float64
Helgravconst float64
Ratme float64
Sunradius float64
// contains filtered or unexported fields
}
GenConst as declared in sweph.h:828
type Interpol ¶
type Interpol struct {
TjdNut0 float64
TjdNut2 float64
NutDpsi0 float64
NutDpsi1 float64
NutDpsi2 float64
NutDeps0 float64
NutDeps1 float64
NutDeps2 float64
// contains filtered or unexported fields
}
Interpol as declared in sweph.h:826
type Nut ¶
type Nut struct {
Tnut float64
Nutlo [2]float64
Snut float64
Cnut float64
Matrix [3][3]float64
// contains filtered or unexported fields
}
Nut as declared in sweph.h:840
type PlanData ¶
type PlanData struct {
Ibdy int32
Iflg int32
Ncoe int32
Lndx0 int32
Nndx int32
Tfstart float64
Tfend float64
Dseg float64
Telem float64
Prot float64
Qrot float64
Dprot float64
Dqrot float64
Rmax float64
Peri float64
Dperi float64
Refep []float64
Tseg0 float64
Tseg1 float64
Segp []float64
Neval int32
Teval float64
Iephe int32
X [6]float64
Xflgs int32
Xreturn [24]float64
// contains filtered or unexported fields
}
PlanData as declared in sweph.h:833
type SavePositions ¶
type SavePositions struct {
Ipl int32
Tsave float64
Iflgsave int32
Xsaves [24]float64
// contains filtered or unexported fields
}
SavePositions as declared in sweph.h:835
type SidData ¶
type SidData struct {
SidMode int32
AyanT0 float64
T0 float64
T0IsUT int32
// contains filtered or unexported fields
}
SidData as declared in sweph.h:842
type SweData ¶
type SweData struct {
EphePathIsSet int32
JplFileIsOpen int32
Fixfp []FILE
Ephepath [256]byte
Jplfnam [256]byte
Jpldenum int32
LastEpheflag int32
GeoposIsSet int32
AyanaIsSet int32
IsOldStarfile int32
EopTjdBeg float64
EopTjdBegHorizons float64
EopTjdEnd float64
EopTjdEndAdd float64
EopDpsiLoaded int32
TidAcc float64
IsTidAccManual int32
InitDtDone int32
SwedIsInitialised int32
DeltaTUserdefIsSet int32
DeltaTUserdef float64
AstG float64
AstH float64
AstDiam float64
Astelem [2560]byte
ISavedPlanetName int32
SavedPlanetName [80]byte
Dpsi []float64
Deps []float64
Timeout int32
AstroModels [8]int32
DoInterpolateNut int32
Interpol Interpol
Fidat [7]FileData
Gcdat GenConst
Pldat [18]PlanData
Nddat [6]PlanData
Savedat [24]SavePositions
Oec Epsilon
Oec2000 Epsilon
Nut Nut
Nut2000 Nut
Nutv Nut
Topd TopoData
Sidd SidData
NFixstarsReal int32
NFixstarsNamed int32
NFixstarsRecords int32
FixedStars []FixedStar
// contains filtered or unexported fields
}
SweData as declared in sweph.h:791
func NewSweDataRef ¶
NewSweDataRef creates a new wrapper struct with underlying reference set to the original C object. Returns nil if the provided pointer to C object is nil too.
func (*SweData) Deref ¶
func (x *SweData) Deref()
Deref uses the underlying reference to C object and fills the wrapping struct with values. Do not forget to call this method whether you get a struct for C object and want to read its values.
func (*SweData) Free ¶
func (x *SweData) Free()
Free invokes alloc map's free mechanism that cleanups any allocated memory using C free. Does nothing if struct is nil or has no allocation map.
func (*SweData) PassRef ¶
func (x *SweData) PassRef() (*C.struct_swe_data, *cgoAllocMap)
PassRef returns the underlying C object, otherwise it will allocate one and set its values from this wrapping struct, counting allocations into an allocation map.
func (SweData) PassValue ¶
func (x SweData) PassValue() (C.struct_swe_data, *cgoAllocMap)
PassValue does the same as PassRef except that it will try to dereference the returned pointer.
func (*SweData) Ref ¶
func (x *SweData) Ref() *C.struct_swe_data
Ref returns the underlying reference to C object or nil if struct is nil.